@@ -49,8 +49,10 @@ class MultiLossesRecorder(callbacks.Callback):
     def on_epoch_end(self, epoch, logs: dict = {}):
         for name, indicator in self.indicators.items():
             for k in indicator:
-                self.train_losses[k].reset()
-                self.test_losses[k].reset()
+                if k in self.train_losses:
+                    self.train_losses[k].reset()
+                if k in self.test_losses:
+                    self.test_losses[k].reset()
 
     @staticmethod
     def summary(phase, average_meter: dict, indicators: dict, losses, logs: dict = {}):
