@@ -17,6 +17,7 @@ import random
 import os
 import subprocess
 import concurrent.futures
+import numbers
 from datetime import datetime
 
 
@@ -97,16 +98,16 @@ class WriterTXT(object):
             self.f.close()
 
 
-def parser_classes(class_name, split=None):
+def parser_classes(class_name):
     """
-    class_dict = {class_name: i for i, class_name in enumerate(class_name)}
-    :param
     :return:
     """
     if isinstance(class_name, str):
-        class_name = read_data(class_name, split=split)
+        class_name = read_data(class_name, split=None)
+    elif isinstance(class_name, numbers.Number):
+        class_name = [str(i) for i in range(int(class_name))]
     if isinstance(class_name, list):
-        class_dict = {class_name: i for i, class_name in enumerate(class_name)}
+        class_dict = {str(class_name): i for i, class_name in enumerate(class_name)}
     elif isinstance(class_name, dict):
         class_dict = class_name
     else:
@@ -700,7 +701,8 @@ def get_files_lists(image_dir, subname="", postfix=["*.jpg", "*.png"], shuffle=F
     elif image_dir.endswith(".txt"):
         data_root = os.path.dirname(image_dir)
         image_list = read_data(image_dir)
-        image_list = [os.path.join(data_root, subname, str(name[0]) + ".jpg") for name in image_list]
+        if subname:
+            image_list = [os.path.join(data_root, subname, str(n[0]) + postfix[0][1:]) for n in image_list]
     elif os.path.isdir(image_dir):
         image_list = get_files(image_dir, postfix=postfix)
     elif os.path.isfile(image_dir):
@@ -872,6 +874,22 @@ def check_files(files_list, sizeTh=1 * 1024, isRemove=False):
     return files_list
 
 
+def get_set_inter_union_diff(set1, set2):
+    """
+    intersection(交集),union(并集),difference(差集)
+    :return:
+    """
+    # 两个列表的差集
+    difference = list(set(set1) ^ set(set2))
+    # 获取两个list 的交集
+    intersection = list(set(set1) & set(set2))
+    # 获取两个list 的并集
+    union = list(set(set1) | set(set2))
+    dset1 = list(set(set1) - set(set2))  # 去除set1中含有set2的元素
+    dset2 = list(set(set2) - set(set1))  # 去除set2中含有set1的元素
+    return intersection, union, difference
+
+
 def get_files_id(file_list):
     """
     :param file_list:
