@@ -235,16 +235,14 @@ def cv_show_image(title, image, type='rgb', waitKey=0):
     return img
 
 
-def show_images_list(name, images_list, type='bgr', waitKey=0):
+def show_images_list(name, images_list, waitKey=0):
     out = image_hstack(images_list)
-    if type == 'rgb':
-        out = cv2.cvtColor(out, cv2.COLOR_RGB2BGR)  # 将BGR转为RGB
     cv2.imshow(name, out)
     cv2.waitKey(waitKey)
-    return out
 
 
 def image_hstack(images):
+    """图像左右拼接"""
     img_new = images[0]
     shape = img_new.shape
     for i in range(1, len(images)):
@@ -257,6 +255,20 @@ def image_hstack(images):
     return img_new
 
 
+def image_vstack(images):
+    """图像上下拼接"""
+    img_new = images[0]
+    shape = img_new.shape
+    for i in range(1, len(images)):
+        img = images[i]
+        if not shape == img.shape:
+            img = cv2.resize(img, dsize=(shape[1], shape[0]))
+        if len(img.shape) == 2:
+            img = cv2.cvtColor(img, cv2.COLOR_GRAY2BGR)
+        img_new = np.vstack((img_new, img))
+    return img_new
+
+
 def image_fliplr(image):
     '''
     左右翻转
@@ -655,9 +667,9 @@ def image_boxes_resize_padding(image, input_size, boxes=None, color=(0, 0, 0)):
     out = cv2.resize(image, (new_size[0], new_size[1]))
     out = cv2.copyMakeBorder(out, top, bottom, left, right, cv2.BORDER_CONSTANT, value=color)  # add border
     if not boxes is None and len(boxes) > 0:
-        boxes = boxes * scale
-        boxes = boxes + [left, top, left, top]
-    return out, boxes
+        boxes[:] = boxes[:] * scale
+        boxes[:] = boxes[:] + [left, top, left, top]
+    return out
 
 
 def image_boxes_resize_padding_inverse(image_size, input_size, boxes=None):
@@ -672,8 +684,8 @@ def image_boxes_resize_padding_inverse(image_size, input_size, boxes=None):
     top, bottom = pad_h // 2, pad_h - (pad_h // 2)
     left, right = pad_w // 2, pad_w - (pad_w // 2)
     if not boxes is None and len(boxes) > 0:
-        boxes = boxes - [left, top, left, top]
-        boxes = boxes / scale
+        boxes[:] = boxes[:] - [left, top, left, top]
+        boxes[:] = boxes[:] / scale
     return boxes
 
 
@@ -988,9 +1000,9 @@ def show_image_rects_text(title, rgb_image, rects, rects_name, color=None, drawT
     return rgb_image
 
 
-def draw_image_detection_rects(rgb_image, rects, probs, lables, boxes_name=None, color=None):
+def draw_image_detection_rects(rgb_image, rects, probs, labels, class_name=None):
     bboxes = rects2bboxes(rects)
-    rgb_image = draw_image_detection_bboxes(rgb_image, bboxes, probs, lables, boxes_name, color)
+    rgb_image = draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, class_name)
     return rgb_image
 
 
@@ -1014,7 +1026,7 @@ def flat_data(data):
     return data
 
 
-def draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, boxes_name=None, color=None):
+def draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, class_name=None):
     '''
     :param title:
     :param rgb_image:
@@ -1023,35 +1035,27 @@ def draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, boxes_name=Non
     :param labels:
     :return:
     '''
-    labels = flat_data(labels)
-    probs = flat_data(probs)
-    class_set = list(CLASS_SET)
-    if not class_set:
-        class_set = list(set(labels))
-    if not boxes_name:
-        boxes_name = combile_label_prob(labels, probs)
-    # bgr_image = cv2.cvtColor(rgb_image, cv2.COLOR_RGB2BGR)
-    # color_map=list(matplotlib.colors.cnames.values())
-    # color_map=list(reversed(color_map))
-    set_color = color
-    for l, name, box in zip(labels, boxes_name, bboxes):
-        if not color:
-            cls_id = class_set.index(l)
-            set_color = get_color(cls_id)
+    labels = np.asarray(labels, dtype=np.int32).reshape(-1)
+    probs = np.asarray(probs).reshape(-1)
+    for label, box, prob in zip(labels, bboxes, probs):
+        set_color = get_color(label)
         box = [int(b) for b in box]
+        if class_name:
+            label = class_name[label]
+        boxes_name = "{}:{:3.3f}".format(label, prob)
         # cv2.rectangle(bgr_image, (crop_type[0], crop_type[1]), (crop_type[2], crop_type[3]), (0, 255, 0), 2, 8, 0)
         # cv2.putText(bgr_image, name, (crop_type[0], crop_type[1]), cv2.FONT_HERSHEY_SIMPLEX, 0.8, (0, 0, 255), thickness=2)
         # cv2.rectangle(bgr_image, (crop_type[0], crop_type[1]), (crop_type[2], crop_type[3]), color, 2, 8, 0)
         # cv2.putText(bgr_image, str(name), (crop_type[0], crop_type[1]), cv2.FONT_HERSHEY_SIMPLEX, 0.8, color, thickness=2)
-        custom_bbox_line(rgb_image, box, set_color, name, drawType="custom")
+        custom_bbox_line(rgb_image, box, set_color, boxes_name, drawType="custom")
     # cv2.imshow(title, bgr_image)
     # cv2.waitKey(0)
     # rgb_image = cv2.cvtColor(bgr_image, cv2.COLOR_BGR2RGB)
     return rgb_image
 
 
-def show_image_detection_bboxes(title, rgb_image, bboxes, probs, lables, color=None, waitKey=0):
-    rgb_image = draw_image_detection_bboxes(rgb_image, bboxes, probs, lables, color=color)
+def show_image_detection_bboxes(title, rgb_image, bboxes, probs, labels, class_name=None, waitKey=0):
+    rgb_image = draw_image_detection_bboxes(rgb_image, bboxes, probs, labels, class_name)
     cv_show_image(title, rgb_image, waitKey=waitKey)
     return rgb_image
 
@@ -1427,7 +1431,7 @@ def draw_image_arrowed_lines(image,
 
 def draw_image_polylines(image, points, color=(0, 0, 255)):
     '''
-    # points是三维坐标，分别表示(多边形个数，多边形坐标点x,多边形坐标点y)
+    # points是三维坐标，分别表示(多边形个数，多边形坐标点x,多边形坐标点y)=(num_polylines,num_point,2)
     points = np.asarray([[[100, 100], [200, 100], [400, 200]],
                          [[500, 600], [300, 400], [500, 700]]]
                          )
@@ -1437,7 +1441,25 @@ def draw_image_polylines(image, points, color=(0, 0, 255)):
     参数4 color：必选参数。用于设置多边形的颜色
     参数5 lineType：可选参数。用于设置线段的类型，可选8（8邻接连接线-默认）、4（4邻接连接线）和cv2.LINE_AA 为抗锯齿
     '''
-    image = cv2.polylines(image, points, isClosed=True, color=color)  # 画任意多边形
+    points = np.asarray(points, dtype=np.int32)
+    image = cv2.polylines(image, points, isClosed=True, color=color, thickness=2)  # 画任意多边形
+    return image
+
+
+def draw_image_fillPoly(image, points, color=(0, 0, 255)):
+    '''
+    # points是三维坐标，分别表示(多边形个数，多边形坐标点x,多边形坐标点y)=(num_polylines,num_point,2)
+    points = np.asarray([[[100, 100], [200, 100], [400, 200]],
+                         [[500, 600], [300, 400], [500, 700]]]
+                         )
+    cv2.polylines(image,points,True,(255,0,0))  #画任意多边形
+    参数2 pts：多边形的顶点坐标(按顺序)，points是三维坐标，分别表示(多边形个数，多边形坐标点x,多边形坐标点y)
+    参数3 isClosed：必选参数。用于设置绘制的折线是否关闭，若设置为True，则从折线的最后一个顶点到其第一个顶点会自动绘制一条线进行闭合。
+    参数4 color：必选参数。用于设置多边形的颜色
+    参数5 lineType：可选参数。用于设置线段的类型，可选8（8邻接连接线-默认）、4（4邻接连接线）和cv2.LINE_AA 为抗锯齿
+    '''
+    points = np.asarray(points, dtype=np.int32)
+    image = cv2.fillPoly(image, points, color=color)
     return image
 
 
@@ -1483,7 +1505,7 @@ def pil_paste_image(im, mask, start_point=(0, 0)):
     """
     out = Image.fromarray(im)
     mask = Image.fromarray(mask)
-    out.paste(mask, start_point)  # fix a bug
+    out.paste(mask, start_point.copy())  # fix a bug
     return np.asarray(out)
 
 
@@ -2294,6 +2316,7 @@ class CVVideo():
         count = 0
         while True:
             isSuccess, frame = video_cap.read()
+            # frame = video_cap.set(cv2.CAP_PROP_POS_FRAMES, count)
             if not isSuccess:
                 break
             if count % detect_freq == 0:
