@@ -14,7 +14,8 @@ class SummaryWriter():
     def __init__(self, log_dir, *args, **kwargs):
         self.tensorboard = None
         if log_dir:
-            self.tensorboard = tensorboard.SummaryWriter(log_dir=log_dir, *args, **kwargs)
+            # 修复tensorboard版本BUG
+            self.tensorboard = tensorboard.SummaryWriter(log_dir, *args, **kwargs)
 
     def add_scalar(self, *args, **kwargs):
         if self.tensorboard:
